Module combinators

Module combinators 

Structs

Difference
Hard difference between two SDFs.
Intersection
Hard intersection of two SDFs.
IntersectionContainer
Hard intersection of N SDFs stored in some container, like a Vec for example.
IntersectionIterator
Hard intersection of N SDFs stored in some iterator.
SDifferenceCircular
Not yet implemented
SDifferenceCircularGeometrical
Not yet implemented
SDifferenceCubic
Not yet implemented
SDifferenceExponential
Smooth difference of two SDFs using the smooth_max_exponential function.
SDifferenceQuadratic
Not yet implemented
SDifferenceQuartic
Not yet implemented
SDifferenceRoot
Not yet implemented
SDifferenceSigmoid
Not yet implemented
SIntersectionCircular
Not yet implemented
SIntersectionCircularGeometrical
Not yet implemented
SIntersectionCubic
Not yet implemented
SIntersectionExponential
Smooth intersection of two SDFs using the smooth_max_exponential function.
SIntersectionQuadratic
Not yet implemented
SIntersectionQuartic
Not yet implemented
SIntersectionRoot
Not yet implemented
SIntersectionSigmoid
Not yet implemented
SUnionCircular
Not yet implemented
SUnionCircularGeometrical
Not yet implemented
SUnionCubic
Not yet implemented
SUnionExponential
Smooth union of two SDFs using the smooth_min_exponential function.
SUnionQuadratic
Not yet implemented
SUnionQuartic
Not yet implemented
SUnionRoot
Not yet implemented
SUnionSigmoid
Smooth union of two SDFs using the smooth_min_sigmoid function.
Union
Hard union of two SDFs.
UnionContainer
Hard union of N SDFs stored in some container, like a Vec for example.
UnionIterator
Hard union of N SDFs stored in some iterator.

Traits

SdfCombinationOperations
SdfContainerCombinationOperations
SdfIteratorCombinationOperations