IntersectionContainer

Struct IntersectionContainer 

pub struct IntersectionContainer<T, Scalar: Float, State: SdfState<Scalar, DIM>, const DIM: usize>
where for<'a> &'a T: IntoIterator, for<'a> <&'a T as IntoIterator>::Item: Sdf<Scalar, DIM, State = State>,
{ /* private fields */ }
Hard intersection of N SDFs stored in some container, like a Vec for example.

See SdfContainerCombinationOperators for more information on how to use this.