Cube

Struct Cube 

pub struct Cube;
A N dimension cube of side length 1.

If we need a rectangle, see Cuboid. This primitive is centered at the origin, and has side lengths of 1.

It implements Sdf<Scalar, DIM, State = ()>.

Example

use lightwalk::prelude::*;

let sdf = Cube;

// This is required to hint the dimension and scalar type of the SDF. In practice,
// the compiler probably already has enough information to go off of.
let distance = sdf.distance([1.0, 2.0]);